API Documentation
=================

.. automodapi:: astropy_helpers.setup_helpers
   :no-main-docstr:

.. automodapi:: astropy_helpers.version_helpers
   :no-main-docstr:

.. automodapi:: astropy_helpers.openmp_helpers
   :no-main-docstr:

.. automodapi:: astropy_helpers.git_helpers
   :no-main-docstr:
